Case History

## Principal Bench at Bengaluru

## Case Details

Case Type : CRL.P
Filing Number: 5792/2024Filing Date: 14-06-2024
Registration Number: 5658/2024 Registration Date: 18-06-2024
CNR Number: KAHC01-033768-2024

## Case Status

First Hearing Date :
Next Hearing Date: Next Date is not given
Stage of Case: ORDERS
Coram : 1492M.NAGAPRASANNA Bench : Single Bench State : KARNATAKA District : BENGALURU Judicial : Judicial Section Causelist Name : Cause List No. 1 Short Order : HEARD-Judmt Reserved Not Before Me : Unknown

## Petitioner and Advocate

1) ROHIT TIWARI
Advocate- DHANUSH MENON
2) ANTONY VINAY KUMAR B

## Respondent and Advocate

1) STATE OF KARNATAKA
2) SUDARSHAN H V

## Subordinate Court Information

Court Number and Name: OTHERS
Case Number and Year: 0
Case Decision Date : : --state:
District:

## IA Details

IA Number | Party | Date of Filing | Next Date | IA Status
--- | --- | --- | --- | ---
Interim Application/1/2024 Classification : Stay | P1 | 14-06-2024 | 19-06-2024 | Disposed

## FIR Details

State: KARNATAKA
District: BENGALURU
Police Station: INDIRANAGAR PS
FIR Number: 155
Year: 2024

## History of Case Hearing

Cause List Type | Judge | Business On Date | Hearing Date | Purpose of hearing
--- | --- | --- | --- | ---
Cause List No. 1 | M.NAGAPRASANNA |  | 19-06-2024 | FRESH MATTER/S
Cause List No. 1 | M.NAGAPRASANNA | 19-06-2024 | 04-07-2024 | FRESH MATTER/S
Cause List No. 1 | M.NAGAPRASANNA | 04-07-2024 |  | ORDERS

## Orders

Order Number | Order on | Judge | Order Date | Order Details

## Category Details

Category | CRL.P ( 112 )
Sub Category | 482-U/S 482 ( 8 )

## Document Details

Sr. No. | Document No. | Date of Receiving | Filed by | Name of Advocate | Document Filed
--- | --- | --- | --- | --- | ---
1 | 1 | 14-06-2024 | P1 |  | Vakalat
2 | 2 | 19-06-2024 | P1 |  | Process Memo